################
User Manual
################

.. toctree::
   :glob:
   :hidden:

   definitions
   researcher_interface
   participation_flow

This section of the documentation is written for the users of the Data Donation Module.
That is, researchers who set up data donation projects to collect data for their research.

**Introduction**

The Data Donation Module (DDM) is an open-source web/Django application for researchers to collect data donations.
It is developed by the Media Use and Effects Division at the University of Zurich.

It is intended to be hosted at an institutional level (e.g., a university, a university division, or a research conglomerate)
as it provides the possibility to host multiple independent data donation projects simultaneously.
Nevertheless, it is also possible to use it for single projects.

This part of the documentation is addressed at the users of the Data Donation Module (usually the researchers) and will explain:

- Core principles of the Data Donation Module.
- How to navigate the user interface.
- How to set up a data donation project.
- How to monitor an ongoing data donation project.
- How to download and work with the collected data.

Readers interested in setting up DDM for institutional use or their own research should turn to: :doc:`../admin/index`.


**Core Components**


.. todo::
    Move this section to a more technical part of the documentation (or delete it).

Building upon the described data donation process, the DDM includes the following components:

* **Project**:
* **Blueprints**:
    * *Donation Blueprint*:
    * *Zip Container*:
    * *Instructions*:
* **Questions**:
